@@ -187,7 +187,7 @@ hierarchy_new_folder (ExchangeHierarchy *hier, EFolder *folder,
 	internal_uri = e_folder_exchange_get_internal_uri (folder);
 
 	/* This should ideally not be needed. But, this causes a problem when the
-	server has identical folder names [ internal_uri ] for folders. Very much
+	server has identical folder names[ internal_uri ] for folders. Very much
 	possible in the case of favorite folders */
 	if (g_hash_table_lookup (EXCHANGE_HIERARCHY_WEBDAV (hier)->priv->folders_by_internal_path,
 				(gchar *)e2k_uri_path (internal_uri)))
@@ -311,8 +311,8 @@ create_folder (ExchangeHierarchy *hier, EFolder *parent,
 	gint i, mode;
 
 	exchange_account_is_offline (hier->account, &mode);
-        if (mode != ONLINE_MODE)
-                return EXCHANGE_ACCOUNT_FOLDER_OFFLINE;
+	if (mode != ONLINE_MODE)
+		return EXCHANGE_ACCOUNT_FOLDER_OFFLINE;
 
 	for (i = 0; folder_types[i].component; i++) {
 		if (!strcmp (folder_types[i].component, type))
@@ -361,10 +361,10 @@ remove_folder (ExchangeHierarchy *hier, EFolder *folder)
 	E2kHTTPStatus status;
 	gint mode;
 
-        exchange_account_is_offline (hier->account, &mode);
+	exchange_account_is_offline (hier->account, &mode);
 
-        if (mode != ONLINE_MODE)
-                return EXCHANGE_ACCOUNT_FOLDER_OFFLINE;
+	if (mode != ONLINE_MODE)
+		return EXCHANGE_ACCOUNT_FOLDER_OFFLINE;
 
 	if (folder == hier->toplevel)
 		return EXCHANGE_ACCOUNT_FOLDER_PERMISSION_DENIED;
@@ -375,7 +375,7 @@ remove_folder (ExchangeHierarchy *hier, EFolder *folder)
 
 		/* update the folder size info */
 		exchange_account_folder_size_remove (hier->account,
-					e_folder_get_name(folder));
+					e_folder_get_name (folder));
 		return EXCHANGE_ACCOUNT_FOLDER_OK;
 	} else
 		return EXCHANGE_ACCOUNT_FOLDER_GENERIC_ERROR;
@@ -394,8 +394,8 @@ xfer_folder (ExchangeHierarchy *hier, EFolder *source,
 	gint mode;
 
 	exchange_account_is_offline (hier->account, &mode);
-        if (mode != ONLINE_MODE)
-                return EXCHANGE_ACCOUNT_FOLDER_OFFLINE;
+	if (mode != ONLINE_MODE)
+		return EXCHANGE_ACCOUNT_FOLDER_OFFLINE;
 
 	if (source == hier->toplevel)
 		return EXCHANGE_ACCOUNT_FOLDER_GENERIC_ERROR;
@@ -701,7 +701,7 @@ scan_subtree (ExchangeHierarchy *hier, EFolder *parent, gint mode)
 	EFolder *folder, *tmp;
 	GPtrArray *folders;
 	gint i;
-	gdouble fsize_d;
+	gdouble fsize_d = 0.0;
 	const gchar *name, *folder_size, *deleted_items_uri, *int_uri;
 	gboolean personal = ( EXCHANGE_HIERARCHY (hwd)->type == EXCHANGE_HIERARCHY_PERSONAL );
 
